from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShareLinksCommentsConfig(AppConfig):
    name = "share_links.apps.share_links_comments"
    verbose_name = _("Share links comments")
