# Generated by Django 3.2.12 on 2022-05-04 20:58

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("share_links", "0002_alter_link_file"),
    ]

    operations = [
        migrations.AddField(
            model_name="linktranslation",
            name="title",
            field=models.CharField(
                blank=True, max_length=2000, null=True, verbose_name="Title"
            ),
        ),
    ]
