# Generated by Django 4.1.1 on 2023-06-10 14:58

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "share_links",
            "0008_collection_collectionlink_collectiontranslation_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="link",
            name="allow_override_language",
            field=models.BooleanField(
                default=False,
                help_text="Management commands will try to fetch the language from the lang attribute.",
                verbose_name="Allow override language?",
            ),
        ),
        migrations.AddField(
            model_name="link",
            name="allow_override_title",
            field=models.BooleanField(
                default=False,
                help_text="Management commands will try to fetch the title from the website <title> tag.",
                verbose_name="Allow override title?",
            ),
        ),
        migrations.AlterField(
            model_name="collectiontranslation",
            name="name",
            field=models.CharField(
                help_text="The name of the collection.",
                max_length=1024,
                verbose_name="Name",
            ),
        ),
    ]
