# Generated by Django 4.1.1 on 2022-11-27 22:20

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("share_links", "0005_link_added_by"),
    ]

    operations = [
        migrations.DeleteModel(
            name="HistoryLink",
        ),
        migrations.DeleteModel(
            name="HistoryTag",
        ),
    ]
