# Generated by Django 3.2.12 on 2022-03-27 18:31

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("share_links", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="link",
            name="file",
            field=models.FileField(
                blank=True,
                help_text="Upload pdf or screenshot of the page. If this field is empty and USE_WEASYPRINT is set to True (currently set to False), then the pdf will be auto-generated using weasyprint.",
                null=True,
                upload_to="files/",
            ),
        ),
    ]
