# Generated by Django 4.1.1 on 2022-12-20 12:54

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("contenttypes", "0002_remove_content_type_name"),
        ("share_links_comments", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="commentwithcaptcha",
            options={
                "verbose_name": "Moderate comments",
                "verbose_name_plural": "Moderate comments",
            },
        ),
        migrations.AlterField(
            model_name="commentwithcaptcha",
            name="content_type",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="content_type_set_for_%(class)s",
                to="contenttypes.contenttype",
                verbose_name="content type",
            ),
        ),
        migrations.AlterField(
            model_name="commentwithcaptcha",
            name="user",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="%(class)s_comments",
                to=settings.AUTH_USER_MODEL,
                verbose_name="user",
            ),
        ),
    ]
