# Generated by Django 3.2.13 on 2022-08-26 21:05

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("share_links", "0003_linktranslation_title"),
    ]

    operations = [
        migrations.AddField(
            model_name="link",
            name="online",
            field=models.BooleanField(
                default=True,
                help_text="Uncheck this box if the link is not online anymore (will provide the web archive link instead of the original link).",
            ),
        ),
    ]
